Coverage for pygeodesy/rhumb/__init__.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''Package of lazily imported C{rhumb} modules L{rhumb.aux_}, L{rhumb.ekx} and L{rhumb.solve}.

5

6@note: C{S12} area calculations in classes L{RhumbAux} and L{RhumbLineAux} depend on class

7 L{AuxDST} which requires U{numpy<https://PyPI.org/project/numpy>} to be installed,

8 version 1.16 or newer.

9'''

10 from pygeodesy.lazily import _ALL_LAZY, _ALL_OTHER, _lazy_import_as, _unLazy0

11

12 __all__ = _ALL_LAZY.rhumb

13 __version__ = '25.12.06'

14

15 if _unLazy0: # or _isfrozen

16 from pygeodesy.rhumb.aux_ import RhumbAux, RhumbLineAux

17 from pygeodesy.rhumb.ekx import Rhumb, RhumbLine

18 from pygeodesy.rhumb.solve import RhumbSolve, RhumbLineSolve, \

19 RhumbSolve7Tuple, Rhumb8Tuple # in .karney

20

21 __all__ += _ALL_OTHER(RhumbAux, RhumbLineAux, Rhumb, RhumbLine,

22 RhumbSolve, RhumbLineSolve, RhumbSolve7Tuple, Rhumb8Tuple)

23 assert _ALL_LAZY.rhumb_aux_ + _ALL_LAZY.rhumb_ekx + _ALL_LAZY.rhumb_solve == __all__

24

25 else: # lazily import modules and exported attrs

26 __getattr__ = _lazy_import_as(__name__)

27

28# **) MIT License

29#

30# Copyright (C) 2018-2026 -- mrJean1 at Gmail -- All Rights Reserved.

31#

32# Permission is hereby granted, free of charge, to any person obtaining a

33# copy of this software and associated documentation files (the "Software"),

34# to deal in the Software without restriction, including without limitation

35# the rights to use, copy, modify, merge, publish, distribute, sublicense,

36# and/or sell copies of the Software, and to permit persons to whom the

37# Software is furnished to do so, subject to the following conditions:

38#

39# The above copyright notice and this permission notice shall be included

40# in all copies or substantial portions of the Software.

41#

42# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

43# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

44# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

45# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

46# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

47# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

48# OTHER DEALINGS IN THE SOFTWARE.